.. _ureports:

logilab.common.ureports package
===============================

Submodules
----------

logilab.common.ureports.docbook\_writer module
----------------------------------------------

.. automodule:: logilab.common.ureports.docbook_writer
    :members:
    :undoc-members:
    :show-inheritance:

logilab.common.ureports.html\_writer module
-------------------------------------------

.. automodule:: logilab.common.ureports.html_writer
    :members:
    :undoc-members:
    :show-inheritance:

logilab.common.ureports.nodes module
------------------------------------

.. automodule:: logilab.common.ureports.nodes
    :members:
    :undoc-members:
    :show-inheritance:

logilab.common.ureports.text\_writer module
-------------------------------------------

.. automodule:: logilab.common.ureports.text_writer
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: logilab.common.ureports
    :members:
    :undoc-members:
    :show-inheritance:
